@@ -1,9 +1,10 @@
 import os.path
 import hashlib
 import time
+import functools
 
 from unstdlib.standard.functools_ import memoized
-from unstdlib.standard.list_ import iterate_items
+from unstdlib.standard.list_ import iterate_items, iterate
 
 try:
     import markupsafe
@@ -14,7 +15,8 @@ except ImportError:
 
 
 __all__ = [
-    'get_cache_buster', 'literal', 'tag', 'javascript_link', 'stylesheet_link',
+    'get_cache_buster', 'literal', 'tag', 'tag_builder',
+    'javascript_link', 'stylesheet_link',
 ]
 
 
@@ -76,11 +78,15 @@ def get_cache_buster(src_path, method='importtime'):
 def _generate_dom_attrs(attrs, allow_no_value=True):
     """ Yield compiled DOM attribute key-value strings.
 
-    If the value is `True`, then it is treated as no-value."""
+    If the value is `True`, then it is treated as no-value. If `None`, then it
+    is skipped.
+    """
     for attr in iterate_items(attrs):
         if isinstance(attr, basestring):
             attr = (attr, True)
         key, value = attr
+        if value is None:
+            continue
         if value is True and not allow_no_value:
             value = key  # E.g. <option checked="true" />
         if value is True:
@@ -109,7 +115,8 @@ def tag(tagname, content='', attrs=None):
 
     :param content:
         Optional content of the DOM element. If `None`, then the element is
-        self-closed. By default, the content is an empty string.
+        self-closed. By default, the content is an empty string. Supports
+        iterables like generators.
 
     :param attrs:
         Optional dictionary-like collection of attributes for the DOM element.
@@ -124,14 +131,34 @@ def tag(tagname, content='', attrs=None):
         u'<script src="/static/js/core.js" type="text/javascript"></script>'
         >>> tag('meta', content=None, attrs=dict(content='"quotedquotes"'))
         u'<meta content="\\\\"quotedquotes\\\\"" />'
+        >>> tag('ul', (tag('li', str(i)) for i in xrange(3)))
+        u'<ul><li>0</li><li>1</li><li>2</li></ul>'
     """
     attrs_str = attrs and ' '.join(_generate_dom_attrs(attrs))
     open_tag = tagname
     if attrs_str:
         open_tag += ' ' + attrs_str
-    if content or isinstance(content, basestring):
-        return literal('<%s>%s</%s>' % (open_tag, content, tagname))
-    return literal('<%s />' % open_tag)
+
+    if content is None:
+        return literal('<%s />' % open_tag)
+
+    content = ''.join(iterate(content, unless=(basestring, literal)))
+    return literal('<%s>%s</%s>' % (open_tag, content, tagname))
+
+
+def tag_builder(tagnames):
+    """ Create tag-generating callables for more DSL-y goodness.
+
+    :param tagnames:
+        List of tag names to generate builders for.
+
+    Example::
+
+        >>> ul, li = tag_builder(['ul', 'li'])
+        >>> ul(li(ch) for ch in 'abc')
+        u'<ul><li>a</li><li>b</li><li>c</li></ul>'
+    """
+    return [functools.partial(tag, t) for t in tagnames]
 
 
 def javascript_link(src_url, src_path=None, cache_bust=None, content='', extra_attrs=None):
@@ -216,38 +243,6 @@ def stylesheet_link(src_url, src_path=None, cache_bust=None, content='', extra_a
     return tag('link', content=content, attrs=attrs)
 
 
-### Backwards compatibility (will be removed in v1.6):
-__all__ += ['html_tag', 'html_javascript_link', 'html_stylesheet_link']
-
-import warnings
-
-def html_tag(*args, **kw):
-    '''
-    This function has been renamed to `tag`. Use that instead.
-    Backwards-compatibility will be removed in v1.6.
-    '''
-    warnings.warn("Renamed to `tag`", DeprecationWarning)
-    return tag(*args, **kw)
-
-
-def html_javascript_link(*args, **kw):
-    '''
-    This function has been renamed to `javascript_link`. Use that instead.
-    Backwards-compatibility will be removed in v1.6.
-    '''
-    warnings.warn("Renamed to `javascript_link`", DeprecationWarning)
-    return javascript_link(*args, **kw)
-
-
-def html_stylesheet_link(*args, **kw):
-    '''
-    This function has been renamed to `stylesheet_link`. Use that instead.
-    Backwards-compatibility will be removed in v1.6.
-    '''
-    warnings.warn("Renamed to `stylesheet_link`", DeprecationWarning)
-    return stylesheet_link(*args, **kw)
-
-
 if __name__ == "__main__":
     import doctest
     doctest.testmod(optionflags=doctest.ELLIPSIS)
