@@ -17,7 +17,7 @@ __all__ = [
     'random_string',
     'number_to_string', 'string_to_number', 'number_to_bytes', 'bytes_to_number',
     'dollars_to_cents',
-    'to_str', 'to_unicode', 'to_int',
+    'to_str', 'to_unicode', 'to_int', 'to_float',
     'format_int',
     'slugify',
 ]
@@ -289,6 +289,46 @@ def to_int(s, default=0):
         return default
 
 
+_infs=set([float("inf"), float("-inf")])
+
+def to_float(s, default=0.0, allow_nan=False):
+    """
+    Return input converted into a float. If failed, then return ``default``.
+
+    Note that, by default, ``allow_nan=False``, so ``to_float`` will not return
+    ``nan``, ``inf``, or ``-inf``.
+
+    Examples::
+
+        >>> to_float('1.5')
+        1.5
+        >>> to_float(1)
+        1.0
+        >>> to_float('')
+        0.0
+        >>> to_float('nan')
+        0.0
+        >>> to_float('inf')
+        0.0
+        >>> to_float('-inf', allow_nan=True)
+        -inf
+        >>> to_float(None)
+        0.0
+        >>> to_float(0, default='Empty')
+        0.0
+        >>> to_float(None, default='Empty')
+        'Empty'
+    """
+    try:
+        f = float(s)
+    except (TypeError, ValueError):
+        return default
+    if not allow_nan:
+        if f != f or f in _infs:
+            return default
+    return f
+
+
 def format_int(n, singular=_Default, plural=_Default):
     """
     Return `singular.format(n)` if n is 1, or `plural.format(n)` otherwise. If
